@@ -5,7 +5,7 @@ Entrypoint for tap_sailthru.
 import singer
 from singer import utils
 
-from tap_sailthru.discover import discover
+from tap_sailthru.discover import discover as _discover
 from tap_sailthru.sync import sync
 
 REQUIRED_CONFIG_KEYS = ["start_date", "api_key", "api_secret", "user_agent"]
@@ -22,14 +22,14 @@ def main():
 
     # If discover flag was passed, run discovery mode and dump output to stdout
     if args.discover:
-        catalog = discover()
+        catalog = _discover(args.config)
         catalog.dump()
     # Otherwise run in sync mode
     else:
         if args.catalog:
             catalog = args.catalog
         else:
-            catalog = discover()
+            catalog = _discover(args.config)
         sync(args.config, args.state, catalog)
 
 
